# List of changes to permissive-slugify

## Unreleased

## 1.0.0 - 2019-01-13
### Added
 - Add extras_require and cmdclass
 - Use pytest
 - Uses CodeCov
 
### Changed
- Update copyright
- Rename to permissive-slugify (#7)

### Fixed
- UnicodeDecodeError on setup.py (#5)
- Remove easy_install in README

### Removed
 - File cleanup: Remove unnecessary files
 